@@ -1,6 +1,8 @@
 # infra
 from .interface import AsyncRunnable, LazyLoadable
-from .interface import MessageTypes, ChannelTypes, ChannelPrivacyTypes, EventTypes, GuildMuteTypes, SlowModeTypes
+from .interface import (MessageTypes, ChannelTypes, ChannelPrivacyTypes, EventTypes, GuildMuteTypes, SlowModeTypes,
+                        RoleTypes)
+from .interface import RoleTypes
 from .cert import Cert
 from .receiver import Receiver, WebhookReceiver, WebsocketReceiver
 from .requester import HTTPRequester
@@ -9,9 +11,9 @@ from .client import Client
 
 # concepts
 from .role import Role
-from .user import User, GuildUser
+from .user import User
 from .channel import Channel, PublicTextChannel, PrivateChannel, PublicChannel
-from .guild import Guild
+from .guild import Guild, GuildUser
 from .context import Context
 from .message import RawMessage, Message, PublicMessage, PrivateMessage, Event
 # extensions
